Learn R Programming

wPerm (version 1.0.1)

energy:

Energy Consumption

Description

Last year's energy consumptions for independent random samples of households in the four U.S. regions.

Usage

data("energy")

Arguments

Format

A data frame with 20 observations on the following 2 variables.
ENERGY
a numeric vector
REGION
a factor with levels Midwest Northeast South West

Details

The Energy Information Administration gathers data on residential energy consumption and expenditures and publishes its findings in Residential Energy Consumption Survey. Independent random samples of households in the four U.S. regions yielded the data on last year's energy consumptions presented in the energy dataset. The data are displayed to the nearest 10 million BTU.

Examples

Run this code
data(energy)
str(energy)
attach(energy)
plot(ENERGY ~ REGION)
detach(energy)

Run the code above in your browser using DataLab