Learn R Programming

wPerm (version 1.0.1)

perm.ind.loc: Independent-Samples Permutation Test for Difference in Location

Description

Performs a permutation (randomization) test for difference in location based on independent samples from two populations.

Usage

perm.ind.loc(x, y, parameter, stacked = TRUE, variable = NULL,
             alternative = c("two.sided", "less", "greater"),
             R = 9999)

Arguments

x
a numeric vector of observations of the variable (stacked case) or a numeric vector of data values representing the first of the two samples (unstacked case).
y
a vector of corresponding population identifiers (stacked case) or a numeric vector of data values representing the second of the two samples (unstacked case).
parameter
the location parameter under consideration (e.g., mean, trimmed mean).
stacked
a logical value (default TRUE) indicating whether the data are stacked.
variable
an optional character string that gives the name of the variable under consideration; ignored if stacked is TRUE.
alternative
a character string specifying the alternative hypothesis; must be one of "two.sided" (default), "less", or "greater".
R
number of replications (default = 9999)

Value

  • A list with class "perm.ts.ind" containing the following components:
  • StackedTRUE if the data are stacked, FALSE otherwise.
  • Perm.valuesthe values of the test statistic obtained from the permutations.
  • Headerthe main title for the output.
  • Variablethe name of the variable under consideration or NULL.
  • Pop.1the first population.
  • Pop.2the second population.
  • n.1the sample size for the first population.
  • n.2the sample size for the second population.
  • Statisticthe test statistic.
  • Observedthe observed value of the test statistic.
  • Nullthe null hypothesis; here, always identical.
  • Alternativethe alternative hypothesis.
  • P.valuethe P-value or a statement like P < 0.001.
  • p.valuethe P-value.

concept

  • permutation tests
  • randomization tests
  • tests for difference in location
  • independent-samples inferences

Details

The null hypothesis is that the distributions of the variable on the two populations are identical---"identical". The possible alternative hypotheses are: Two tailed ("two.sided"): The distribution of the variable on the first population has either systematically smaller values or systematically larger values than that of the variable on the second population---"shifted". Left tailed ("less"): The distribution of the variable on the first population has systematically smaller values than that of the variable on the second population---"shifted.left". Right tailed ("greater"): The distribution of the variable on the first population has systematically larger values than that of the variable on the second population---"shifted.right".

Examples

Run this code
# Annual salaries, in thousands of dollars, for independent samples of
# faculty in private and public institutions.
data("salary")
str(salary)
attach(salary)
# Note that the data are stacked.

# Independent-samples permutation test to decide whether there is a
# difference in location for salaries of faculty in private and public
# institutions, using the mean as the location parameter.
perm.ind.loc(SALARY, TYPE, mean)

# Independent-samples permutation test to decide whether faculty in private
# institutions have systematically larger salaries than those in public
# institutions, using the 20% trimmed mean as the location parameter.
tr20.mean <- function(x) mean(x, trim = 0.20)
perm.ind.loc(SALARY, TYPE, tr20.mean, alternative = "greater")

detach(salary)  # clean up.

Run the code above in your browser using DataLab