Learn R Programming

wPerm (version 1.0.1)

perm.paired.loc: Paired-Sample Permutation Test for Difference in Location

Description

Performs a permutation (randomization) test for difference in location based on a paired sample.

Usage

perm.paired.loc(x, y, parameter, variable = NULL,
                alternative = c("two.sided", "less", "greater"),
                R = 9999)

Arguments

x
a numeric vector of data values representing the first components of the pairs.
y
a numeric vector of data values representing the second components of the pairs.
parameter
the location parameter under consideration (e.g., mean, trimmed mean).
variable
an optional character string that gives the name of the variable under consideration.
alternative
a character string specifying the alternative hypothesis; must be one of "two.sided" (default), "less", or "greater".
R
number of replications (default = 9999).

Value

  • A list with class "perm.paired.loc" containing the following components:
  • Perm.valuesthe values of the test statistic obtained from the permutations.
  • Headerthe main title for the output.
  • Variablethe name of the variable under consideration or NULL.
  • Pop.1the first population.
  • Pop.2the second population.
  • nthe sample size.
  • Statisticthe test statistic.
  • Observedthe observed value of the test statistic.
  • Nullthe null hypothesis; here, always identical.
  • Alternativethe alternative hypothesis.
  • P.valuethe P-value or a statement like P < 0.001.
  • p.valuethe P-value.

concept

  • permutation tests
  • randomization tests
  • tests for difference in location
  • paired-sample inferences

Details

The null hypothesis is that the distributions of the variable on the two populations are identical---"identical". The possible alternative hypotheses are: Two tailed ("two.sided"): The distribution of the variable on the first population has either systematically smaller values or systematically larger values than that of the variable on the second population---"shifted". Left tailed ("less"): The distribution of the variable on the first population has systematically smaller values than that of the variable on the second population---"shifted.left". Right tailed ("greater"): The distribution of the variable on the first population has systematically larger values than that of the variable on the second population---"shifted.right".

Examples

Run this code
# Ages of a sample of 10 heterosexual spouses.
data("spouse.ages")
str(spouse.ages)
attach(spouse.ages)

# Paired-sample permutation test to decide whether there is a difference
# in location for age distributions of married men and married women,
# using the mean as the location parameter. Variable named "Age".
perm.paired.loc(HUSBAND, WIFE, mean, "Age")

# Paired-sample permutation test to decide whether married men have
# systematically greater ages than married women, using the 10% trimmed
# mean as the location parameter.
tr10.mean <- function(x) mean(x, trim = 0.10)
perm.paired.loc(HUSBAND, WIFE, tr10.mean, alternative = "greater")

detach(spouse.ages)  # clean up.

Run the code above in your browser using DataLab