powered by
Print Output for Class "perm.cs.hom"
perm.cs.hom
This is a method for the function print() to print objects of class "perm.cs.hom".
print()
"print"(x, ...)
This print method summarizes and formats for easy reading the results of a permutation function with output list of class "perm.cs.hom".
perm.hom.test