powered by
Print Output for Class "perm.oneway.anova"
perm.oneway.anova
This is a method for the function print() to print objects of class "perm.oneway.anova".
print()
"print"(x, ...)
This print method summarizes and formats for easy reading the results of a permutation function with output list of class "perm.oneway.anova".