powered by
Print Output for Class "perm.paired.loc"
perm.paired.loc
This is a method for the function print() to print objects of class "perm.paired.loc".
print()
"print"(x, ...)
This print method summarizes and formats for easy reading the results of a permutation function with output list of class "perm.paired.loc".