Learn R Programming

wPerm (version 1.0.1)

print.perm.two.var:

Print Output for Class "perm.two.var"

Description

This is a method for the function print() to print objects of class "perm.two.var".

Usage

"print"(x, ...)

Arguments

x
an object of class "perm.two.var".
...
further arguments passed to or from other methods.

Value

The perm.two.var object is returned invisibly.

Details

This print method summarizes and formats for easy reading the results of a permutation function with output list of class "perm.two.var".

See Also

perm.relation, perm.ind.test