Learn R Programming

wPerm (version 1.0.1)

spouse.ages:

Ages of Married People

Description

Ages, in years, of a random sample of 10 heterosexual married couples.

Usage

data("spouse.ages")

Arguments

Format

A data frame with 10 observations on the following 2 variables.
HUSBAND
a numeric vector
WIFE
a numeric vector

Details

The U.S. Census Bureau publishes information on the ages of married people in Current Population Reports. A random sample of 10 heterosexual married couples gave the data on ages, in years, shown in the spouse.ages dataset.

Examples

Run this code
data(spouse.ages)
str(spouse.ages)
attach(spouse.ages)
detach(spouse.ages)

Run the code above in your browser using DataLab