Learn R Programming

wPerm (version 1.0.1)

wPerm-package: Permutation Tests

Description

Supplies permutation-test alternatives to traditional hypothesis-test procedures such as two-sample tests for means, medians, and standard deviations; correlation tests; tests for homogeneity and independence; and more. Suitable for general audiences, including individual and group users, introductory statistics courses, and more advanced statistics courses that desire an introduction to permutation tests.

Arguments

Details

Package:
wPerm
Type:
Package
Version:
1.0.1
Date:
2015-11-03
License:
GPL (>= 2)