Learn R Programming

wPerm (version 1.0.1)

water:

Water Price vs Distance from Museum

Description

Prices, in euros, of a 50cl bottle of water and distances, in meters, of convenience stores from the Contemporary Art Museum in El Raval, Barcelona.

Usage

data("water")

Arguments

Format

A data frame with 10 observations on the following 2 variables.
DISTANCE
a numeric vector
PRICE
a numeric vector

Barcelona Field Studies Centre, http://geographyfieldwork.com/SpearmansRank.htm.

Details

Does the price of a convenience-store item, such as a bottle of water, decrease as distance from the Contemporary Art Museum in El Raval, Barcelona, increases? A sample of 10 convenience stores yielded the data presented in the water dataset on price, in euros, of a 50cl bottle of water and distance, in meters, of the convenience store from the Contemporary Art Museum.

Examples

Run this code
data(water)
str(water)
plot(water)
attach(water)
detach(water)

Run the code above in your browser using DataLab